@@ -1,19 +1,19 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd2.2.7"
+#define HOST_OS "freebsd2.2.8"
 #define HOST_OS_NAME "freebsd2"
-#define HOST_OS_VERSION "2.2.7"
+#define HOST_OS_VERSION "2.2.8"
 #define HOST_ARCH "i386"
-#define HOST_NAME "bmt.cs.columbia.edu"
+#define HOST_NAME "dingo.mcl.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Tue Jul  4 17:50:22 EDT 2000"
+#define CONFIG_DATE "Tue Jul  4 19:55:30 EDT 2000"
 #define PACKAGE "am-utils"
 #define VERSION "6.0.4s6"
 #define PACKAGE "am-utils"
 #define VERSION "6.0.4s6"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "2.2.7"
+#define HOST_HEADER_VERSION "2.2.8"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA 1
